@@ -1,5 +1,3 @@
-
-
 from datetime import datetime, timezone
 import os
 import queue
@@ -76,7 +74,7 @@ class FtServer(object):
         self.db_client_test = MongoClient("127.0.0.1", 27017, connectTimeoutMS=10000)
         self.test_trading_account = self.db_client_test['tradingAccount']
 
-        self.get_acccount_info()
+        self.get_account_info()
 
         self.buy_orderlock = threading.Lock()
         self.sell_orderlock = threading.Lock()
@@ -175,7 +173,7 @@ class FtServer(object):
             exit(0)
 
     #not use
-    def get_acccount_info(self):
+    def get_account_info(self):
         for acc in self.accounts_run:
             product_name = self.product_names[acc]
             query = {"product_name": product_name}
@@ -727,10 +725,12 @@ class FtServer(object):
 
             self.token = data['data']['token']
             accs = data['data']['accs']
+            self.logger.info(f"[login] logged (token){self.token} (data){data}")
             for myacc in accs:
                 trade_acc = myacc['trade_acc']
                 self.broker_id[trade_acc] = myacc['broker_id']
-                self.logger.info(f"[login] logged (token){self.token} (data){data}")
+                self.logger.info(f"(trade_acc){trade_acc} broker_id{self.broker_id[trade_acc]}")
+                
         except Exception as e:
             err = traceback.format_exc()
             self.send_to_feishu(err)
@@ -1363,4 +1363,4 @@ if __name__ == "__main__":
     td = FtServer(args.config_filename, args.end_time)
     td.start()
 
-    td.join()
+    td.join()
\ No newline at end of file
